summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/religion.cc
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/religion.cc')
-rw-r--r--crawl-ref/source/religion.cc14
1 files changed, 9 insertions, 5 deletions
diff --git a/crawl-ref/source/religion.cc b/crawl-ref/source/religion.cc
index e1d969745c..a924c6c1df 100644
--- a/crawl-ref/source/religion.cc
+++ b/crawl-ref/source/religion.cc
@@ -1555,8 +1555,10 @@ bool bless_follower(monsters *follower,
if (chance > 2)
return (false);
- // Choose a random follower in LOS, preferably a named one (10% chance).
- follower = choose_random_nearby_monster(0, suitable, true, true);
+ // Choose a random follower in LOS, preferably a named one, or a
+ // priestly one for Beogh (10% chance).
+ follower = choose_random_nearby_monster(0, suitable, true, true,
+ god == GOD_BEOGH);
if (!follower)
{
@@ -1564,7 +1566,8 @@ bool bless_follower(monsters *follower,
return (false);
// Try again, without the LOS restriction (5% chance).
- follower = choose_random_nearby_monster(0, suitable, false, true);
+ follower = choose_random_nearby_monster(0, suitable, false, true,
+ god == GOD_BEOGH);
if (!follower)
{
@@ -1572,8 +1575,9 @@ bool bless_follower(monsters *follower,
return (false);
// Try *again*, on the entire level (2.5% chance).
- follower = choose_random_monster_on_level(0, suitable,
- false, false, true);
+ follower = choose_random_monster_on_level(0, suitable, false,
+ false, true,
+ god == GOD_BEOGH);
if (!follower)
{